==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GdkGraphics2D__24DrawState.h <==
// class gnu.java.awt.peer.gtk.GdkGraphics2D$DrawState

// class file dependencies
// @dep_class fddce248c407d98f gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_
#define _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object;
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Composite$object;
struct _jc_java_awt_Font$object;
struct _jc_java_awt_Paint$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_awt_Stroke$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method$_init$43430f0157a1a46a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method$restore$92ac05160c60d23c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method_info$restore$92ac05160c60d23c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods {
	void	(*restore$92ac05160c60d23c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs {
	struct _jc_object	*paint;
	struct _jc_object	*stroke;
	struct _jc_java_awt_Color$object	*fg;
	struct _jc_java_awt_Color$object	*bg;
	struct _jc_object	*clip;
	struct _jc_java_awt_geom_AffineTransform$object	*transform;
	struct _jc_java_awt_Font$object	*font;
	struct _jc_object	*comp;
	struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs {
    _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object {
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/peer/gtk/GdkGraphics2D__24DrawState.h <==
// class gnu.java.awt.peer.gtk.GdkGraphics2D$DrawState

// class file dependencies
// @dep_class 29a4ce3b2c8b633e gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_
#define _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object;
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Composite$object;
struct _jc_java_awt_Font$object;
struct _jc_java_awt_Paint$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_awt_Stroke$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method$_init$43430f0157a1a46a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method$restore$92ac05160c60d23c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$method_info$restore$92ac05160c60d23c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods {
	void	(*restore$92ac05160c60d23c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object *, struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vmethods	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs {
	struct _jc_object	*paint;
	struct _jc_object	*stroke;
	struct _jc_java_awt_Color$object	*fg;
	struct _jc_java_awt_Color$object	*bg;
	struct _jc_object	*clip;
	struct _jc_java_awt_geom_AffineTransform$object	*transform;
	struct _jc_java_awt_Font$object	*font;
	struct _jc_object	*comp;
	struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs {
    _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_refs	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$sub_nonrefs	gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$object {
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$vtype _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkGraphics2D__24DrawState_H_ */
